@@ -16,7 +16,9 @@ Credits:
     * Eric Bloemen (HUB, usability research)
     * Eddy Borghers (University of Antwerp, case development)
     * Christophe Croux (K.U.Leuven, statistics research)
+    * Antoon De Rycker (Taylor's University, research)
     * Claude Doom (HUB, usability research)
+    * Ian E. Holliday (Aston University, course development, research)
     * Dirk Janssens (Lessius, course development)
     * Christine Lourdon (KdG, course development)
     * Koen Milis (HUB, usability research)
