@@ -5,7 +5,7 @@ function(network="", colors="", weights="") {
   g <- graph.data.frame(network$edges, directed=T, vertices=network$vertices)
   if (length(colors)>1) V(g)$color <- colors
   if (length(weights)>1) E(g)$weight <- weights
-  tkplot(g)
+  tkplot(g, layout=layout.circle, vertex.label=V(g)$name, vertex.shape="rectangle", vertex.size=50, asp=FALSE)
   return(g)
 }
 
